@@ -1,24 +1,25 @@
-import logging as _logging
-import sys as _sys
-import threading as _threading
-import uuid as _uuid
+from __future__ import absolute_import
 
-try:
-    # Python 2.x
-    import Queue as _queue
-except ImportError:
-    # Python 3.x
-    import queue as _queue  # noqa
+import logging
+import sys
+import threading
+import uuid
 
-from pykka.exceptions import ActorDeadError as _ActorDeadError
-from pykka.future import ThreadingFuture as _ThreadingFuture
-from pykka.proxy import ActorProxy as _ActorProxy
-from pykka.registry import ActorRegistry as _ActorRegistry
+from pykka.exceptions import ActorDeadError
+from pykka.proxy import ActorProxy
+from pykka.registry import ActorRegistry
 
-_logger = _logging.getLogger('pykka')
+
+__all__ = [
+    'Actor',
+    'ActorRef',
+]
+
+logger = logging.getLogger('pykka')
 
 
 class Actor(object):
+
     """
     To create an actor:
 
@@ -94,8 +95,8 @@ class Actor(object):
         assert obj.actor_ref is not None, (
             'Actor.__init__() have not been called. '
             'Did you forget to call super() in your override?')
-        _ActorRegistry.register(obj.actor_ref)
-        _logger.debug('Starting %s', obj)
+        ActorRegistry.register(obj.actor_ref)
+        logger.debug('Starting %s', obj)
         obj._start_actor_loop()
         return obj.actor_ref
 
@@ -149,9 +150,9 @@ class Actor(object):
         :meth:`__init__` is called before the actor is started and registered
         in :class:`ActorRegistry <pykka.ActorRegistry>`.
         """
-        self.actor_urn = _uuid.uuid4().urn
+        self.actor_urn = uuid.uuid4().urn
         self.actor_inbox = self._create_actor_inbox()
-        self.actor_stopped = _threading.Event()
+        self.actor_stopped = threading.Event()
 
         self.actor_ref = ActorRef(self)
 
@@ -173,13 +174,13 @@ class Actor(object):
         """
         Stops the actor immediately without processing the rest of the inbox.
         """
-        _ActorRegistry.unregister(self.actor_ref)
+        ActorRegistry.unregister(self.actor_ref)
         self.actor_stopped.set()
-        _logger.debug('Stopped %s', self)
+        logger.debug('Stopped %s', self)
         try:
             self.on_stop()
         except Exception:
-            self._handle_failure(*_sys.exc_info())
+            self._handle_failure(*sys.exc_info())
 
     def _actor_loop(self):
         """
@@ -190,7 +191,7 @@ class Actor(object):
         try:
             self.on_start()
         except Exception:
-            self._handle_failure(*_sys.exc_info())
+            self._handle_failure(*sys.exc_info())
 
         while not self.actor_stopped.is_set():
             message = self.actor_inbox.get()
@@ -202,23 +203,23 @@ class Actor(object):
                     reply_to.set(response)
             except Exception:
                 if reply_to:
-                    _logger.debug(
+                    logger.debug(
                         'Exception returned from %s to caller:' % self,
-                        exc_info=_sys.exc_info())
+                        exc_info=sys.exc_info())
                     reply_to.set_exception()
                 else:
-                    self._handle_failure(*_sys.exc_info())
+                    self._handle_failure(*sys.exc_info())
                     try:
-                        self.on_failure(*_sys.exc_info())
+                        self.on_failure(*sys.exc_info())
                     except Exception:
-                        self._handle_failure(*_sys.exc_info())
+                        self._handle_failure(*sys.exc_info())
             except BaseException:
-                exception_value = _sys.exc_info()[1]
-                _logger.debug(
+                exception_value = sys.exc_info()[1]
+                logger.debug(
                     '%s in %s. Stopping all actors.' %
                     (repr(exception_value), self))
                 self._stop()
-                _ActorRegistry.stop_all()
+                ActorRegistry.stop_all()
 
         while not self.actor_inbox.empty():
             msg = self.actor_inbox.get()
@@ -227,7 +228,7 @@ class Actor(object):
                 if msg.get('command') == 'pykka_stop':
                     reply_to.set(None)
                 else:
-                    reply_to.set_exception(_ActorDeadError(
+                    reply_to.set_exception(ActorDeadError(
                         '%s stopped before handling the message' %
                         self.actor_ref))
 
@@ -263,10 +264,10 @@ class Actor(object):
 
     def _handle_failure(self, exception_type, exception_value, traceback):
         """Logs unexpected failures, unregisters and stops the actor."""
-        _logger.error(
+        logger.error(
             'Unhandled exception in %s:' % self,
             exc_info=(exception_type, exception_value, traceback))
-        _ActorRegistry.unregister(self.actor_ref)
+        ActorRegistry.unregister(self.actor_ref)
         self.actor_stopped.set()
 
     def on_failure(self, exception_type, exception_value, traceback):
@@ -314,7 +315,7 @@ class Actor(object):
 
         :returns: anything that should be sent as a reply to the sender
         """
-        _logger.warning('Unexpected message received by %s: %s', self, message)
+        logger.warning('Unexpected message received by %s: %s', self, message)
 
     def _get_attribute_from_path(self, attr_path):
         """
@@ -326,48 +327,8 @@ class Actor(object):
         return attr
 
 
-class ThreadingActor(Actor):
-    """
-    :class:`ThreadingActor` implements :class:`Actor` using regular Python
-    threads.
-
-    This implementation is slower than :class:`GeventActor
-    <pykka.gevent.GeventActor>`, but can be used in a process with other
-    threads that are not Pykka actors.
-    """
-
-    use_daemon_thread = False
-    """
-    A boolean value indicating whether this actor is executed on a thread that
-    is a daemon thread (:class:`True`) or not (:class:`False`). This must be
-    set before :meth:`pykka.Actor.start` is called, otherwise
-    :exc:`RuntimeError` is raised.
-
-    The entire Python program exits when no alive non-daemon threads are left.
-    This means that an actor running on a daemon thread may be interrupted at
-    any time, and there is no guarantee that cleanup will be done or that
-    :meth:`pykka.Actor.on_stop` will be called.
-
-    Actors do not inherit the daemon flag from the actor that made it. It
-    always has to be set explicitly for the actor to run on a daemonic thread.
-    """
-
-    @staticmethod
-    def _create_actor_inbox():
-        return _queue.Queue()
-
-    @staticmethod
-    def _create_future():
-        return _ThreadingFuture()
-
-    def _start_actor_loop(self):
-        thread = _threading.Thread(target=self._actor_loop)
-        thread.name = thread.name.replace('Thread', self.__class__.__name__)
-        thread.daemon = self.use_daemon_thread
-        thread.start()
-
-
 class ActorRef(object):
+
     """
     Reference to a running actor which may safely be passed around.
 
@@ -434,7 +395,7 @@ class ActorRef(object):
         :return: nothing
         """
         if not self.is_alive():
-            raise _ActorDeadError('%s not found' % self)
+            raise ActorDeadError('%s not found' % self)
         self.actor_inbox.put(message)
 
     def ask(self, message, block=True, timeout=None):
@@ -468,7 +429,7 @@ class ActorRef(object):
         message['pykka_reply_to'] = future
         try:
             self.tell(message)
-        except _ActorDeadError:
+        except ActorDeadError:
             future.set_exception()
         if block:
             return future.get(timeout=timeout)
@@ -501,7 +462,7 @@ class ActorRef(object):
             try:
                 ask_future.get(timeout=timeout)
                 return True
-            except _ActorDeadError:
+            except ActorDeadError:
                 return False
 
         converted_future = ask_future.__class__()
@@ -528,4 +489,4 @@ class ActorRef(object):
         :raise: :exc:`pykka.ActorDeadError` if actor is not available
         :return: :class:`pykka.ActorProxy`
         """
-        return _ActorProxy(self)
+        return ActorProxy(self)
